NGX - Heros Devices 0.10.3 documentation

Skip to content
Back to top
View this page

# NGX

From: Rohde Schwarz

Class: `herosdevices.hardware.rohde_schwarz.ngx.NGX`

Driver Quality Index: beta

Driver for Rohde Schwarz NGX Power Supplies using the VISA interface.

The desired channels have to configured using the channel index (starting from 1) and a user-friendly channel name. For each channel, the HERO gains properties channel_name_ current, voltage, power and status. In addition, current and voltage can be set using the property.

Querying can also occur for the configured number of channels simultaneously by using the class-level properties.

All properties are provided as observable data.

Arguments

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.rohde_schwarz.ngx.NGX` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
resource | <class ‘str’> |  | VISA resource identifier e.g. TCPIP::my_device_address::INSTR.
channels | tuple[tuple[int, str], …] | ((1, ‘ch1’),) | List of tuples of channel index and channel name.
keep_alive | <class ‘bool’> | True | Keep VISA connection open.

Example JSON for BOSS

The following JSON strings can be used to start a HERO device representation of `NGX` using BOSS.

    {
        "_id": "ngp804",
        "classname": "herosdevices.hardware.rohde_schwarz.NGX",
        "arguments": {
            "resource": "TCPIP::my_device_address::INSTR",
            "channels": [
                [
                    1,
                    "ch1"
                ],
                [
                    2,
                    "ch2"
                ],
                [
                    3,
                    "ch3"
                ],
                [
                    4,
                    "ch4"
                ]
            ]
        },
        "datasource": {
            "async": false,
            "interval": 15
        }
    }

from examples/rohde_schwarz/ngp804.json

    {
        "_id": "my_NGX",
        "classname": "herosdevices.hardware.rohde_schwarz.ngx.NGX",
        "arguments": {
            "resource": "<class 'str'>",
            "channels": [
                [
                    1,
                    "ch1"
                ]
            ],
            "keep_alive": true
        }
    }

generated from signature

Inheritance